@@ -24,6 +24,7 @@ def create_dbt_pod_operator(
     retries: int = 1,
     retry_delay: timedelta = timedelta(seconds=5),
     namespace: str = "default",
+    startup_timeout_seconds: int=360
 ):
     return kubernetes_pod_operator.KubernetesPodOperator(
         init_containers=[create_read_bucket_init_container(bucket_dbt_path)],
@@ -38,7 +39,7 @@ def create_dbt_pod_operator(
                 name="data", mount_path="data", sub_path=None, read_only=False
             )
         ],
-        startup_timeout_seconds=360,
+        startup_timeout_seconds=startup_timeout_seconds,
         volumes=[Volume(name="data", configs={})],
         image=os.getenv("KNADA_DBT_IMAGE", "navikt/knada-dbt:4"),
         retries=retries,
@@ -100,7 +101,7 @@ def create_nb_pod_operator(
 
     env_vars = {
         "LOG_ENABLED": "true" if log_output else "false",
-        "NOTEBOOK_PATH": f"data/{Path(nb_path).parent}",
+        "NOTEBOOK_PATH": f"/workspace/{Path(nb_path).parent}",
         "NOTEBOOK_NAME": Path(nb_path).name,
         "REQUESTS_CA_BUNDLE": "/etc/ssl/certs/ca-certificates.crt",
         "NLS_LANG": nls_lang
@@ -117,7 +118,7 @@ def create_nb_pod_operator(
         namespace=namespace,
         volume_mounts=[
             VolumeMount(
-                name="data", mount_path="data", sub_path=None, read_only=False
+                name="data", mount_path="/workspace", sub_path=None, read_only=False
             )
         ],
         startup_timeout_seconds=360,
